translate.storage.workflow.State

Package translate :: Package storage :: Module workflow :: Class State |
[hide private]
[frames] | no frames]

# Class State

source code

Instance Methods | [hide private]
__init__(self, name, enter_action=None, leave_action=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__eq__(self, rhs) | source code
__repr__(self) repr(x) | source code
enter(self, obj) | source code
leave(self, obj) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, name, enter_action=None, leave_action=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __repr__(self) (Representation operator) | source code
repr(x) Overrides: object.__repr__ (inherited documentation)